# This is an automatically generated file converting from the apm format

import casadi as cs

def hs058():
    # The optimal objective is (if given in):
    f_opt = 3.19033354957
    x_opt = cs.DM([-0.786151, 0.618034])
    x = cs.MX.sym('x', 2)
    obj = cs.MX.zeros(1, 1)
    x0 = cs.DM.zeros(2, 1)
    lbx = -cs.inf*cs.DM.ones(2, 1)
    ubx = cs.inf*cs.DM.ones(2, 1)
    g = cs.MX.zeros(3, 1)
    lbg = -cs.inf*cs.DM.ones(3, 1)
    ubg = cs.inf*cs.DM.ones(3, 1)
    
    x0[0]= -2
    lbx[0]=-2
    ubx[0]=0.5
    x0[1]= 1
    
    lbg[0] = 0
    g[0] =  x[1]**2 - x[0]
    lbg[1] = 0
    g[1] =  x[0]**2 - x[1]
    lbg[2] = 1
    g[2] =  x[0]**2 + x[1]**2
    obj = 100*(x[1]-x[0]**2)**2+(1-x[0])**2
    
    
    f = obj
    
    return (x_opt, f_opt, x, f, g, lbg, ubg, lbx, ubx, x0)



# This is an automatically generated file converting from the apm format

import casadi as cs

def hs009():
    # The optimal objective is (if given in):
    f_opt = -0.5
    x_opt = cs.DM([-471, -628])
    x = cs.MX.sym('x', 2)
    obj = cs.MX.zeros(1, 1)
    x0 = cs.DM.zeros(2, 1)
    lbx = -cs.inf*cs.DM.ones(2, 1)
    ubx = cs.inf*cs.DM.ones(2, 1)
    g = cs.MX.zeros(1, 1)
    lbg = -cs.inf*cs.DM.ones(1, 1)
    ubg = cs.inf*cs.DM.ones(1, 1)
    
    x0[0]= 0
    x0[1]= 0
    
    lbg[0] =  0
    ubg[0] =  0
    g[0] = 4*x[0] - 3*x[1]
    obj = cs.sin(cs.pi * x[0]/12) * cs.cos(cs.pi * x[1]/16)
    
    
    f = obj
    print('hs009: There are infinitely many solutions (12k-3, 16k-4), k=0 +-1,...')
    return (x_opt, f_opt, x, f, g, lbg, ubg, lbx, ubx, x0)



# This is an automatically generated file converting from the apm format

import casadi as cs

def hs052():
    # The optimal objective is (if given in):
    x_opt = cs.DM([-33/349, 11/349, 180/349, -158/349, 11/349])
    f_opt = 1859/349
    x = cs.MX.sym('x', 5)
    obj = cs.MX.zeros(1, 1)
    x0 = cs.DM.zeros(5, 1)
    lbx = -cs.inf*cs.DM.ones(5, 1)
    ubx = cs.inf*cs.DM.ones(5, 1)
    g = cs.MX.zeros(3, 1)
    lbg = -cs.inf*cs.DM.ones(3, 1)
    ubg = cs.inf*cs.DM.ones(3, 1)
    
    x0[0:5]= 2
    
    lbg[0] =  0
    ubg[0] =  0
    g[0] = x[0] + 3*x[1]
    lbg[1] =  0
    ubg[1] =  0
    g[1] = x[2] +   x[3] - 2*x[4]
    lbg[2] =  0
    ubg[2] =  0
    g[2] = x[1] -   x[4]
    obj = (4*x[0]-x[1])**2 + (x[1]+x[2]-2)**2 + (x[3]-1)**2 + (x[4]-1)**2
    
    
    f = obj
    
    return (x_opt, f_opt, x, f, g, lbg, ubg, lbx, ubx, x0)



# This is an automatically generated file converting from the apm format

import casadi as cs

def hs027():
    # The optimal objective is (if given in):
    x_opt = cs.DM([-1,1,0])
    f_opt = 0.04
    x = cs.MX.sym('x', 3)
    obj = cs.MX.zeros(1, 1)
    x0 = cs.DM.zeros(3, 1)
    lbx = -cs.inf*cs.DM.ones(3, 1)
    ubx = cs.inf*cs.DM.ones(3, 1)
    g = cs.MX.zeros(1, 1)
    lbg = -cs.inf*cs.DM.ones(1, 1)
    ubg = cs.inf*cs.DM.ones(1, 1)
    
    x0[0]= 2
    x0[1]= 2
    x0[2]= 2
    
    lbg[0] =  -1
    ubg[0] =  -1
    g[0] = x[0] + x[2]**2
    obj = (x[0] - 1)**2/100 + (x[1] - x[0]**2)**2
    
    
    f = obj
    
    return (x_opt, f_opt, x, f, g, lbg, ubg, lbx, ubx, x0)



# This is an automatically generated file converting from the apm format

import casadi as cs

def hs031():
    # The optimal objective is (if given in):
    x_opt = cs.DM([1/cs.sqrt(3), cs.sqrt(3), 0])
    f_opt = 6
    x = cs.MX.sym('x', 3)
    obj = cs.MX.zeros(1, 1)
    x0 = cs.DM.zeros(3, 1)
    lbx = -cs.inf*cs.DM.ones(3, 1)
    ubx = cs.inf*cs.DM.ones(3, 1)
    g = cs.MX.zeros(1, 1)
    lbg = -cs.inf*cs.DM.ones(1, 1)
    ubg = cs.inf*cs.DM.ones(1, 1)
    
    x0[0:3]= 1
    
    lbg[0] = 1
    g[0] = x[0] * x[1]
    lbx[0] = -10
    ubx[0] =  10
    lbx[1] = 1
    ubx[1] =  10
    lbx[2] = -10
    ubx[2] =  1
    obj = 9*x[0]**2 + x[1]**2 + 9*x[2]**2
    
    
    f = obj
    
    return (x_opt, f_opt, x, f, g, lbg, ubg, lbx, ubx, x0)
